function strIsNum(%str)
{
    %table = "-.1234567890";
    %len = strlen(%str);
    if(%len == 0)
        return false;
    for(%i = 0; %i < %len; %i ++)
    {
        if(strPos(%table, getSubStr(%str, %i, 1)) == -1)
            return false;
    }
    return true;
}


//The Factory Color String expresses the list of factory colors in a short, colored list, like [1][2][3]... so that they can be previewed at a glance.
//This function runs exactly once, so that this string doesn't have to be generated from the vehicle's data every time the list of colors is requested.
//Assume that the factory colors in a datablock don't change during runtime. (Otherwise, you'd need to run this script each time)
//
//The Shark II has 23 factory colors, so all factoryColorString variables in its VEH script are split into two parts.
//If you have more than 12 colors, use that version of this function and variable.
function lawnmower90vehicle::generateFactoryColorStrings(%this)
{
    //announce("Generating factory color strings...");
    %this.factoryColorString = "";

    //Start with a blank string, then append each factory color in the form of [#] one at a time
    for(%i = 1; %i <= %this.numFactoryColors[%j]; %i++)
    {
        %this.factoryColorString = %this.factoryColorString @ "<color:" @ getWord(%this.factoryColor[%i], 0) @ ">[" @ %i @ "]";
    }
}
lawnmower90vehicle.generateFactoryColorStrings();
//Called it.


//Display the targets available. That is, base, stripe, interior, et cetera.
function lawnmower90vehicle::displayColorTargets(%this, %veh, %c)
{
    //The base color is always there, and, uniquely, it is affected by reColorVehicle. If this is checked, make it look unavailable.
    if(%brick.reColorVehicle) %color = "\c8";
    else if(0 == %veh.colorSchemeTarget)%color= "\c3";
                                  else %color = "\c7";

    %c.chatMessage("            \c4T 0 \c8- " @ %color @ %veh.colorSchemeName[0]);

    //The lawnmower only has two color scheme targets -- base and stripe -- so this for loop runs only once, with %i = 1.
    for(%i = 1; %i < %veh.numColorSchemeTargets; %i++)
    {
        if(%i == 0 || strlen(%veh.colorSchemeNodes[%i]) != 0)
        {
            if(%i == %veh.colorSchemeTarget)
                %color = "\c3";
            else if (getWord(%veh.colorSchemeColor[%i], 3) != 1 || strlen(%veh.colorSchemeNodes[%i]) == 0)
                %color = "\c8";
            else
                %color = "\c7";

            %c.chatMessage("            \c4T " @ %i @ " \c8- " @ %color @ %veh.colorSchemeName[%i]);
        }
    }
}

//Show the factory color string, generated up above.
//This COULD be only one line of code whenever it's needed, except I want to make an exception of Re-Color Vehicle is selected.
//This is the other function where you'll want to take the version from Shark II if you have more than 12 factory colors.
function lawnmower90vehicle::displayFactoryColorString(%this, %veh, %c)
{   
    if(%veh.colorSchemeTarget == 0 && %brick.reColorVehicle)
    {
        %c.chatMessage("    \c7Colors for current target: \c8N/A - \c0Re-Color Vehicle\c6 is checked on the vehicle's spawn brick. Base colors are unavailable.");
    }
    else
    {
        // announce("Factory colors on current target: " @ %this.numFactoryColors[%veh.colorSchemeFactoryColorGroup[%veh.colorSchemeTarget]]);
        %c.chatMessage("    \c7Colors for current target: " @  %this.factoryColorString);
    }

    return;
}

//"Remove" the current paint target. Changing any target to have an alpha of 0 makes it share the base color.
function lawnmower90vehicle::deleteCurrentPaintTarget(%this, %veh, %c, %vehname)
{
    %c.chatMessage();
    %veh.colorSchemeColor[%veh.colorSchemeTarget] = "0 0 0 0";
    %veh.spawnbrick.colorSchemeColor[%this.colorSchemeIdentifier, %veh.colorSchemeTarget] = "0 0 0 0";
    %c.chatMessage(%vehname @ "\c3" @ %veh.colorSchemeName[%veh.colorSchemeTarget] @ "\c6 now matches base color. Paint target changed to \c40: \c3" @ %veh.colorSchemeName[0]);
    %veh.colorSchemeTarget = 0;
    %veh.setNodeColor("ALL", %veh.colorSchemeColor[0]);
    lawnmower90vehicle.displayFactoryColorString(%veh, %c);
    lawnmower90vehicle.displayColorTargets(%veh, %c);
}

function lawnmower90vehicle::VehicleEditHelper(%this, %veh, %c, %arg1, %arg2, %arg3)
{
    %vehname = "\c5LawnMaster '90\c6: ";
    %this = %this.getid();
    %brick = %veh.spawnbrick;
    %ID = %this.colorSchemeIdentifier;

    if(getSimTime() - %c.VEHactivationTimer < 150)
    {
        %c.VEHactivationTimer = getSimTime();
        return %c.chatMessage(%vehname @ "Let's not activate complicated scripts too quickly.");
    }
    %c.VEHactivationTimer = getSimTime();

    if(getTrustLevel(%c, %veh) < 2)
        return %c.chatMessage(%vehname @ "You can't change a vehicle without the owner's trust.");


    if(getSubStr(%arg1, 0, 1) $= "r")
    {
        %c.VEHactivationTimer = %c.VEHactivationTimer + 500;
        %this.setDefaultBrickAttributes(%veh);
        return%c.chatMessage(%vehname @ "Vehicle factory color randomized!");
    }


    if(%arg1 $= "c") //View factory colors in full, individually listed with their names.
    {
        %c.chatMessage("\c0-----\c7LawnMaster '90 \c3"@ %veh.colorSchemeName[%veh.colorSchemeTarget] @"\c7 Factory Colors\c0-----");
        // %c.chatMessage("        \c6If you type two numbers, you can use the factory colors for a different target.");

        if(%veh.colorSchemeTarget == 0 && %brick.reColorVehicle)
        {
            %c.chatMessage("\c8N/A - \c0Re-Color Vehicle\c6 is checked on the vehicle's spawn brick. Base colors are unavailable.");
        }
        else 
        {
            for(%i = 1; %i <= %this.numFactoryColors; %i++)
            {
                %c.chatMessage("    \c7/veh \c6" @ %i @ "\c8 - <color:" @ getWord(%this.factoryColor[%i], 0) @ ">[" @ getWords(%this.factoryColor[%i], 1) @ "]");
            }
        }

        return;
    }


    if(strIsNum(%arg1)) //Apply the selected factory color
    {
        if(%veh.colorSchemeTarget == 0 && %brick.reColorVehicle) //Re-Color Vehicle and base color selected. Let the player know why nothing changed.
        {
            return %c.chatMessage("\c0Re-Color Vehicle\c6 is checked on the vehicle's spawn brick. Base colors are unavailable.");
        }

        if(%arg1 > 0 && %arg1 <= %this.numFactoryColors) //Valid factory color choice
        {
            %veh.setNodeColor("ALL", getColorF(getWord(%this.factoryColor[%arg1], 0)));

            if(%veh.colorSchemeTarget == 0)
            {
                %veh.colorSchemeTarget = 1;
                %veh.setNodeColor("ALL", lawnmower90vehicle.getRandomStripeColor(%arg1));
                %veh.colorSchemeTarget = 0;
            }

            return;
        }

        else if(%arg1 == 0 && %veh.colorSchemeTarget != 0) //Setting to 0 means it should match the base color
        {
            return lawnmower90Vehicle.deleteCurrentPaintTarget(%veh, %c, %vehname);
        }
        
        else
        {
            %c.chatMessage(%vehname @ "That is not a valid factory color for \c4" @ %veh.colorSchemeTarget @ ": \c3" @ %veh.colorSchemeName[%veh.colorSchemeTarget]);
            lawnmower90vehicle.displayFactoryColorString(%veh, %c);
            return;
        }
    }

    if(%arg1 $= "t") //Change paint target (from base to stripe/interior etc.)
    {
        if(%arg2 $="") //Cycle to next in list
        {
            %proposedtarget = %veh.colorSchemeTarget + 1;
            if(%proposedtarget >= %veh.numColorSchemeTargets)
                %proposedtarget = 0;
        }
        else if(%arg2 < 0 || %arg2 >= %veh.numColorSchemeTargets || !strIsNum(%arg2)) //Outside the range
        {
            return %c.chatmessage(%vehname @ "That is not a valid color scheme number.");
        }
        else //Number is provided, and it's a valid number. mFloor so that decimals are ignored.
        {
            %proposedtarget = mFloor(%arg2);
        }

        %veh.colorSchemeTarget = %proposedTarget;
        %c.chatMessage(%vehname @ "Paint target changed to \c4" @ %veh.colorSchemeTarget @ ": \c3" @ %veh.colorSchemeName[%veh.colorSchemeTarget]);

        //Now that a target is selected, show the short version of what colors can be applied.
        lawnmower90vehicle.displayFactoryColorString(%veh, %c);
        //Display the list of targets so they can see clearly where they are in the list.
        lawnmower90vehicle.displayColorTargets(%veh, %c);

        return;
    }



    %c.chatMessage("\c8-----\c0LawnMaster '90\c8 - \c0Vehicle Edit Helper\c8-----");
        %c.chatMessage("        \c7/veh \c2R \c8- \c6Randomize factory colors");
        %c.chatMessage("        \c7/veh \c0# \c8- \c6Apply \c0factory color \c7/veh \c0C \c8- \c6View \c0factory colors\c6 and names for current paint target.");
        if(%veh.colorSchemeTarget != 0 && strlen(%veh.colorSchemeNodes[%veh.colorSchemeTarget]) != 0 && getWord(%veh.colorSchemeColor[%veh.colorSchemeTarget], 3) == 1)
        {
        %c.chatMessage("        \c00 \c8- \c6Remove current paint target's color (match base color)");
        }
        lawnmower90vehicle.displayFactoryColorString(%veh, %c);
        %c.chatMessage("        \c7/veh \c4T \c8- \c6Cycle paint target.");
        lawnmower90vehicle.displayColorTargets(%veh, %c);
}